@@ -14,9 +14,9 @@ from pipeline.conf import settings
 from pipeline.utils import to_class, relpath
 from pipeline.exceptions import CompressorError
 
-URL_DETECTOR = r"""url\(['"]{0,1}\s*(.*?)["']{0,1}\)"""
+URL_DETECTOR = r"""url\((['"]){0,1}\s*(.*?)["']{0,1}\)"""
 URL_REPLACER = r"""url\(__EMBED__(.+?)(\?\d+)?\)"""
-NON_REWRITABLE_URL = re.compile(r'^(http:|https:|data:|//)')
+NON_REWRITABLE_URL = re.compile(r'^(#|http:|https:|data:|//)')
 
 DEFAULT_TEMPLATE_FUNC = "template"
 TEMPLATE_FUNC = r"""var template = function(str){var fn = new Function('obj', 'var __p=[],print=function(){__p.push.apply(__p,arguments);};with(obj||{}){__p.push(\''+str.replace(/\\/g, '\\\\').replace(/'/g, "\\'").replace(/<%=([\s\S]+?)%>/g,function(match,code){return "',"+code.replace(/\\'/g, "'")+",'";}).replace(/<%([\s\S]+?)%>/g,function(match,code){return "');"+code.replace(/\\'/g, "'").replace(/[\r\n\t]/g,' ')+"__p.push('";}).replace(/\r/g,'\\r').replace(/\n/g,'\\n').replace(/\t/g,'\\t')+"');}return __p.join('');");return fn;};"""
@@ -127,9 +127,10 @@ class Compressor(object):
         stylesheets = []
         for path in paths:
             def reconstruct(match):
-                asset_path = match.group(1)
+                quote = match.group(1) or ''
+                asset_path = match.group(2)
                 if NON_REWRITABLE_URL.match(asset_path):
-                    return "url(%s)" % asset_path
+                    return "url(%s%s%s)" % (quote, asset_path, quote)
                 asset_url = self.construct_asset_path(asset_path, path,
                                                       output_filename, variant)
                 return "url(%s)" % asset_url
